@@ -27,6 +27,7 @@ class IdfApp(App):
     """
 
     FLASH_ARGS_FILENAME = 'flash_args'
+    FLASH_PROJECT_ARGS_FILENAME = 'flash_project_args'
     FLASH_ARGS_JSON_FILENAME = 'flasher_args.json'
 
     def __init__(
@@ -168,12 +169,15 @@ class IdfApp(App):
     def _parse_flash_args(self) -> List[str]:
         flash_args_filepath = None
         for fn in os.listdir(self.binary_path):
-            if fn == self.FLASH_ARGS_FILENAME:
+            if fn in [self.FLASH_PROJECT_ARGS_FILENAME, self.FLASH_ARGS_FILENAME]:
                 flash_args_filepath = os.path.realpath(os.path.join(self.binary_path, fn))
                 break
 
         if not flash_args_filepath:
-            raise ValueError(f'{self.FLASH_ARGS_FILENAME} not found')
+            raise ValueError(
+                f'{self.FLASH_PROJECT_ARGS_FILENAME} or {self.FLASH_ARGS_FILENAME} '
+                f'is not found under {self.binary_path}'
+            )
 
         with open(flash_args_filepath) as fr:
             return shlex.split(fr.read().strip())
